<?php 
class WPJCE_FilterManager
{
	var $global_data;
	var $post_data;
	var $external_css_to_embed_on_footer = array();
	function __construct()
	{
		//frontend
		add_action('wp_enqueue_scripts', array(&$this, 'enqueue_scripts')); //wp_enqueue_scripts
		//add_action('wp_print_styles', array(&$this, 'enqueue_styles')); //wp_enqueue_scripts
		add_action('wp_head', array(&$this, 'add_code_to_header'));
		add_action('wp_footer', array(&$this, 'add_code_to_footer'));
		
		//admin
		add_action('admin_enqueue_scripts', array(&$this, 'enqueue_scripts')); 
		add_action('admin_head', array(&$this, 'add_code_to_header'));
		add_action('admin_footer', array(&$this, 'add_code_to_footer'));
	}
	function enqueue_scripts()
	{
		global $wpjce_post_model, $wpjce_code_model, $post, $wp;
		
		$current_url = wpjce_get_current_url();
		$this->retrieve_code_data();
				
		/* wpjce_var_dump($this->post_data);*/
		//wpjce_var_dump($this->global_code_data); 
		
		//Look only for external script	
		foreach($this->global_code_data as $elem)
		{
			$can_be_rendered = true;
			if(wpjce_get_value_if_set($elem, 'page-filter', '') != "")
			{
				$can_be_rendered = $wpjce_post_model->url_matches_filter($current_url, $elem['page-filter']);
			}
			if(is_admin() && isset($post) && $post->post_type == "wpjce_custom_code")
			{
				$can_be_rendered = false;
			}
			/* wpjce_var_dump(is_admin());
			wpjce_var_dump($can_be_rendered); */
			if(!$can_be_rendered)
				continue;
			
			//include the scripts
			if(is_array($elem['external-code-id']))
				foreach($elem['external-code-id'] as $external_code_id => $external_code_data)
				{
					$this->enqueue_external_script($external_code_id, $external_code_data);
				}
		
		
		
		}
		
		//Specific page external scripts
		if(isset($this->post_data['external-code-id']) && is_array($this->post_data['external-code-id']) &&	(!isset($_GET['action']) || $_GET['action'] != 'edit'))
			foreach($this->post_data['external-code-id'] as $external_code_id => $external_code_data)
			{
				$this->enqueue_external_script($external_code_id, $external_code_data);
			}
	}
	
	private function enqueue_external_script($external_code_id, $external_code_data)
	{
		global $wpjce_post_model;
		
		$external_code_data['enabled'] = wpjce_get_value_if_set($external_code_data, 'enabled', 'yes');
		if($external_code_data['enabled'] == 'no')
			return;
						
		$is_remote_link = isset($external_code_data['is_remote']) && $external_code_data['is_remote'] == 'true';
		$external_code_url = !$is_remote_link ? $wpjce_post_model->get_attachment_url($external_code_data['value']) : $external_code_data['value'];
				
		switch($external_code_data['type'])
		{
			case 'javascript': wp_enqueue_script('wpjce_script_'.$external_code_id, $external_code_url, array('jquery'), false, $external_code_data['position'] == 'footer'); 
						break;
			case 'css': if($external_code_data['position'] != 'footer')  //Footer script are embedded through the add_code_to_footer() method
							wp_enqueue_style('wpjce_css_'.$external_code_id, $external_code_url );
						else 
							$this->external_css_to_embed_on_footer[$external_code_id] = $external_code_url;
						break;
		}
	}
	function add_code_to_header()
	{
		$this->print_code('header');
	
	}
	function add_code_to_footer()
	{
		$this->print_code('footer');
		
		//Footer external scripts have to be included here
		//wpjce_var_dump($this->external_css_to_embed_on_footer);
		foreach($this->external_css_to_embed_on_footer as $external_code_id => $external_code_url)
			wp_enqueue_style('wpjce_css_'.$external_code_id, $external_code_url );
	}
	private function print_code($position = 'footer')
	{
		global $wpjce_post_model, $post;
		$current_url = wpjce_get_current_url();
		
		//Global 
		foreach($this->global_code_data as $elem)
		{
			$can_be_rendered = true;
			if(wpjce_get_value_if_set($elem, 'page-filter', '') != "")
			{
				$can_be_rendered = $wpjce_post_model->url_matches_filter($current_url, $elem['page-filter']);
			}
			if(is_admin() && isset($post) && $post->post_type == "wpjce_custom_code")
			{
				$can_be_rendered = false;
			}
			if(!$can_be_rendered)
				continue;
			
			//Js
			if($elem['code-position-js'] == $position && wpjce_get_value_if_set($elem, 'js-code', '') != "")
			{
				echo '<script>';
				echo $elem['js-code'];
				echo '</script>';
			}
			//Css
			if($elem['code-position-css'] == $position &&  wpjce_get_value_if_set($elem, 'css-code', '') != "")
			{
				echo '<style>';
				echo $elem['css-code'];
				echo '</style>';
			}
		}
		
		//Specific 
		if(isset($this->post_data['code-position-js']) && $this->post_data['code-position-js'] == $position && $this->post_data['js-code'] != "")
		{
			echo '<script>';
			echo $this->post_data['js-code'];
			echo '</script>';
		}
		if(isset($this->post_data['code-position-css']) && $this->post_data['code-position-css'] == $position && $this->post_data['css-code'] != "")
		{
			echo '<style>';
			echo $this->post_data['css-code'];
			echo '</style>';
		}
	}
	private function retrieve_code_data()
	{
		global $wpjce_post_model, $wpjce_code_model, $post, $wp;
		$specific_post_code_data = array();
		if(isset($post) /* && !is_admin() */)
		{
			$specific_post_code_data = isset($this->post_data) ? $this->post_data : $wpjce_post_model->get_code_data($post->ID);
		}
		if(is_admin() && isset($post) && $post->post_type == "wpjce_custom_code")
		{
			$specific_post_code_data = array();
		}
		
		$global_code_data =  isset($this->global_data) ? $this->global_data : $wpjce_code_model->get_global_code_data();
		
		$this->post_data = $specific_post_code_data;
		$this->global_code_data = $global_code_data;
		//$this->global_code_data['specific_post'] = $this->post_data;
	}
}
?>